@@ -22,12 +22,14 @@ ge <- mxExpectationGREML(V="V",yvars="y", Xvars="x", addOnes=T)
 gff <- mxFitFunctionGREML(dV=c(va="A",ve="I"))
 
 plan <- mxComputeSequence(steps=list(
-	mxComputeGradientDescent(engine=mxOption(NULL,"Default optimizer"),useGradient=TRUE),
+	mxComputeGradientDescent(engine=mxOption(NULL,"Default optimizer")),
 	mxComputeReportExpectation()
 ))
 
 mxdat <- mxData(observed = dat, type="raw", sort=FALSE)
 
+mxOption(NULL,"Analytic Gradients","Yes")
+
 testmod <- mxModel(
 	"GREML_1GRM_1trait", #<--Model name
 	#1x1 matrix containing residual variance component:
@@ -50,13 +52,17 @@ testmod <- mxModel(
 )
 testrun <- mxRun(testmod)
 
+mxOption(NULL,"Analytic Gradients","No")
 testmod2 <- testmod
 testmod2$compute <- mxComputeSequence(steps=list(
-	mxComputeGradientDescent(engine=mxOption(NULL,"Default optimizer"),useGradient=FALSE),
+	mxComputeGradientDescent(engine=mxOption(NULL,"Default optimizer")),
 	mxComputeReportExpectation()
 ))
 testmod2$fitfunction <- mxFitFunctionGREML(autoDerivType="numeric")
 testrun2 <- mxRun(testmod2)
 
 #One thing that definitely should be smaller with analytic gradient is the number of fitfunction evaluations:
-if(testrun$output$evaluations >= testrun2$output$evaluations){stop("models/passing/AnalyticGradientTest.R failed")}
+if(testrun$output$evaluations >= testrun2$output$evaluations){stop("models/nightly/AnalyticGradientTest.R failed")}
+
+mxOption(reset=TRUE)
+options(mxCondenseMatrixSlots=FALSE)
