@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2020 by the individuals mentioned in the source code history
+ *  Copyright 2007-2021 by the individuals mentioned in the source code history
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -33,7 +33,7 @@
 #include "omxExpectation.h"
 #include "glue.h"
 #include "Compute.h"
-#include <Eigen/CholmodSupport>
+#include <RcppEigenCholmod.h>
 #include <RcppEigenWrap.h>
 #include "EnableWarnings.h"
 
@@ -492,7 +492,7 @@ void omxCompleteExpectation(omxExpectation *ox) {
 const std::vector<const char *> &omxExpectation::getDataColumnNames() const
 { return dataColumnNames; }
 
-const Eigen::Map<omxExpectation::DataColumnIndexVector> omxExpectation::getDataColumns()
+const Eigen::Map<omxExpectation::DataColumnIndexVector> omxExpectation::getDataColumns() // NOT const
 {
 	return Eigen::Map<DataColumnIndexVector>(dataColumnsPtr, numDataColumns);
 }
@@ -614,3 +614,40 @@ void omxExpectation::asVector1(FitContext *fc, int row, Eigen::Ref<Eigen::Vector
 
 bool omxExpectation::isTopState() const
 { return currentState->isTopState(); }
+
+int MVNExpectation::numObservedStats()
+{
+  if (strEQ(data->getType(), "raw")) {
+  	/*In SOME cases, when no observations are missing, it is reasonable to reduce a raw dataset 
+  	 down to a set of sufficient statistics (as is done here).  However, that is not justifiable generally.*/
+    if (data->hasSummaryStats()) return numSummaryStats();
+
+    auto &dc = getDataColumns();
+    // More accurate to use sufficient statistics for each missingness pattern? TODO
+    int stats = 0;
+    for (int cx=0; cx < int(dc.size()); ++cx) {
+      stats += data->countObs(dc[cx]);
+    }
+
+    return stats;
+
+  } else if (strEQ(data->getType(), "cov") || strEQ(data->getType(), "cor")) {
+    omxMatrix *cov = omxDataCovariance(data);
+    int size = cov->rows;
+    if (strEQ(data->getType(), "cor")) size -= 1;
+    int stats = triangleLoc1(size);
+    omxMatrix *means = omxDataMeans(data);
+    if (means) stats += means->rows * means->cols;
+    return stats;
+  } else {
+    return NA_INTEGER;
+  }
+}
+
+void MVNExpectation::populateAttr(SEXP algebra)
+{
+	if(0){ //The current implementation is causing issues.
+  	IntegerVector RobStat = Rcpp::wrap(numObservedStats());
+  	Rf_setAttrib(algebra, Rf_install("numStats"), RobStat);
+	}
+}
